@@ -45,6 +45,7 @@ enum op {
 static int _process_channel(const gchar *channel_directory, GKeyFile *kf, const char *identifier,
                             enum op op, struct channel_configuration *defaults,
                             enclosure_filter *filter);
+static void usage(void);
 static void version(void);
 static GKeyFile *_configuration_file_open(const gchar *rcfile);
 static void _configuration_file_close(GKeyFile *kf);
@@ -76,7 +77,7 @@ static gchar *filter_regex = NULL;
 int main(int argc, char **argv)
 {
   enum op op = OP_UPDATE;
-  int i;
+  int i, len;
   int ret = 0;
   gchar **groups;
   gchar *channeldir;
@@ -224,6 +225,15 @@ int main(int argc, char **argv)
 static void version(void)
 {
   g_printf("%s %s\n", PACKAGE, VERSION);
+
+#ifdef ENABLE_ID3LIB
+  g_printf("with ID3 tag support\n");
+#endif
+
+#ifdef ENABLE_GREGEX
+  g_printf("with --filter support\n");
+#endif
+
   g_printf("Copyright (C) 2005-2016 Marius L. Jøhndal <mariuslj at ifi.uio.no>\n");
 }
 
@@ -264,7 +274,7 @@ static void update_callback(void *user_data, channel_action action,
                  enclosure->filename, enclosure->length,
                  channel_info->title);
       } else {
-        g_printf(" * Downloading %s from %s\n",
+        g_printf(" * Downloading %s (unknown length) from %s\n",
                  enclosure->filename,
                  channel_info->title);
       }
@@ -315,8 +325,11 @@ static void catchup_callback(void *user_data, channel_action action, channel_inf
     g_assert(enclosure);
 
     if (verbose)
-      g_printf("Catching up on %s (%ld bytes) from %s\n", enclosure->url, enclosure->length,
-               channel_info->title);
+      if (enclosure->length > 0)
+        g_printf("Catching up on %s (%ld bytes) from %s\n", enclosure->url, enclosure->length,
+                 channel_info->title);
+      else
+        g_printf("Catching up on %s (unknown length) from %s\n", enclosure->url, channel_info->title);
     break;
 
   case CCA_ENCLOSURE_DOWNLOAD_END:
