@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2013-2016 Marius L. Jøhndal
+  Copyright (C) 2013 Marius L. Jøhndal
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -22,8 +22,6 @@
 #endif /* HAVE_CONFIG_H */
 
 #include <stdio.h>
-#include <string.h>
-#include <stdlib.h>
 #include <math.h>
 #include <glib.h>
 #include "progress.h"
@@ -94,9 +92,9 @@ progress_bar *progress_bar_new(long resume_from)
   if (columns) {
     char *endptr;
     long num = strtol(columns, &endptr, 10);
-
-    if ((endptr != columns) && (endptr == columns + strlen(columns)) && (num > 0))
+    if ((endptr != columns) && (endptr == columns + strlen(columns)) && (num > 0)) {
       pb->width = MIN(pb->width, (int)num); /* restrict width of progress bar to avoid insane values */
+    }
   }
 
   g_strfreev(environ);
